body {
  visibility: hidden;
}

.main {
  display: flex;
  flex-wrap: wrap;
  gap: 0.5vw;
  justify-content: space-evenly;
  padding: 0rem;
  padding-bottom: 0.75rem;
  border-radius: 1rem;
  overflow: hidden;
}

/* from the github markdown css */
body.dark .markdown-body {
  color-scheme: dark;
  --color-prettylights-syntax-comment: #8b949e;
  --color-prettylights-syntax-constant: #79c0ff;
  --color-prettylights-syntax-entity: #d2a8ff;
  --color-prettylights-syntax-storage-modifier-import: #c9d1d9;
  --color-prettylights-syntax-entity-tag: #7ee787;
  --color-prettylights-syntax-keyword: #ff7b72;
  --color-prettylights-syntax-string: #a5d6ff;
  --color-prettylights-syntax-variable: #ffa657;
  --color-prettylights-syntax-brackethighlighter-unmatched: #f85149;
  --color-prettylights-syntax-invalid-illegal-text: #f0f6fc;
  --color-prettylights-syntax-invalid-illegal-bg: #8e1519;
  --color-prettylights-syntax-carriage-return-text: #f0f6fc;
  --color-prettylights-syntax-carriage-return-bg: #b62324;
  --color-prettylights-syntax-string-regexp: #7ee787;
  --color-prettylights-syntax-markup-list: #f2cc60;
  --color-prettylights-syntax-markup-heading: #1f6feb;
  --color-prettylights-syntax-markup-italic: #c9d1d9;
  --color-prettylights-syntax-markup-bold: #c9d1d9;
  --color-prettylights-syntax-markup-deleted-text: #ffdcd7;
  --color-prettylights-syntax-markup-deleted-bg: #67060c;
  --color-prettylights-syntax-markup-inserted-text: #aff5b4;
  --color-prettylights-syntax-markup-inserted-bg: #033a16;
  --color-prettylights-syntax-markup-changed-text: #ffdfb6;
  --color-prettylights-syntax-markup-changed-bg: #5a1e02;
  --color-prettylights-syntax-markup-ignored-text: #c9d1d9;
  --color-prettylights-syntax-markup-ignored-bg: #1158c7;
  --color-prettylights-syntax-meta-diff-range: #d2a8ff;
  --color-prettylights-syntax-brackethighlighter-angle: #8b949e;
  --color-prettylights-syntax-sublimelinter-gutter-mark: #484f58;
  --color-prettylights-syntax-constant-other-reference-link: #a5d6ff;
  --color-fg-default: #c9d1d9;
  --color-fg-muted: #8b949e;
  --color-fg-subtle: #6e7681;
  --color-canvas-default: #0d1117;
  --color-canvas-subtle: #161b22;
  --color-border-default: #30363d;
  --color-border-muted: #21262d;
  --color-neutral-muted: rgba(110, 118, 129, 0.4);
  --color-accent-fg: #58a6ff;
  --color-accent-emphasis: #1f6feb;
  --color-attention-subtle: rgba(187, 128, 9, 0.15);
  --color-danger-fg: #f85149;
}

/* from the github markdown css */
body.light .markdown-body {
  color-scheme: light;
  --color-prettylights-syntax-comment: #6e7781;
  --color-prettylights-syntax-constant: #0550ae;
  --color-prettylights-syntax-entity: #8250df;
  --color-prettylights-syntax-storage-modifier-import: #24292f;
  --color-prettylights-syntax-entity-tag: #116329;
  --color-prettylights-syntax-keyword: #cf222e;
  --color-prettylights-syntax-string: #0a3069;
  --color-prettylights-syntax-variable: #953800;
  --color-prettylights-syntax-brackethighlighter-unmatched: #82071e;
  --color-prettylights-syntax-invalid-illegal-text: #f6f8fa;
  --color-prettylights-syntax-invalid-illegal-bg: #82071e;
  --color-prettylights-syntax-carriage-return-text: #f6f8fa;
  --color-prettylights-syntax-carriage-return-bg: #cf222e;
  --color-prettylights-syntax-string-regexp: #116329;
  --color-prettylights-syntax-markup-list: #3b2300;
  --color-prettylights-syntax-markup-heading: #0550ae;
  --color-prettylights-syntax-markup-italic: #24292f;
  --color-prettylights-syntax-markup-bold: #24292f;
  --color-prettylights-syntax-markup-deleted-text: #82071e;
  --color-prettylights-syntax-markup-deleted-bg: #ffebe9;
  --color-prettylights-syntax-markup-inserted-text: #116329;
  --color-prettylights-syntax-markup-inserted-bg: #dafbe1;
  --color-prettylights-syntax-markup-changed-text: #953800;
  --color-prettylights-syntax-markup-changed-bg: #ffd8b5;
  --color-prettylights-syntax-markup-ignored-text: #eaeef2;
  --color-prettylights-syntax-markup-ignored-bg: #0550ae;
  --color-prettylights-syntax-meta-diff-range: #8250df;
  --color-prettylights-syntax-brackethighlighter-angle: #57606a;
  --color-prettylights-syntax-sublimelinter-gutter-mark: #8c959f;
  --color-prettylights-syntax-constant-other-reference-link: #0a3069;
  --color-fg-default: #24292f;
  --color-fg-muted: #57606a;
  --color-fg-subtle: #6e7781;
  --color-canvas-default: #ffffff;
  --color-canvas-subtle: #f6f8fa;
  --color-border-default: #d0d7de;
  --color-border-muted: hsla(210, 18%, 87%, 1);
  --color-neutral-muted: rgba(175, 184, 193, 0.2);
  --color-accent-fg: #0969da;
  --color-accent-emphasis: #0969da;
  --color-attention-subtle: #fff8c5;
  --color-danger-fg: #cf222e;
}

img {
  border-radius: 0.75rem;
}

@media screen and (max-width: 767px) {
  .main {
    gap: 0vw;
  }
}

.page-title {
  padding-left: 0.5rem;
  padding-right: 0.5rem;
}

main.responsive {
  padding: 0rem;
}

article {
  height: 100%;
  width: 100%;
  padding: 0.75rem;
  padding-bottom: 0rem;
}

.main > .post {
  flex-grow: 1;
  max-width: 32%;
}

@media screen and (max-width: 767px) {
  .main > .post {
    min-width: 100%;
  }
  .main > .post:not(:last-child) > article {
    border-bottom: solid var(--outline) 1px;
  }
}

.main > .post > article {
  border-radius: 0;
}

.main > .post > article:hover {
  filter: brightness(130%);
}

.main > .post > article.without-image {
  display: flex;
  flex-direction: column;
  justify-content: space-around;
  min-height: 10dvh;
}

.main > .post > article > .article-meta {
  padding-top: 0.5rem;
}

.main > .post > article > a {
  width: inherit;
}

article.single-post > .markdown-body {
  background-color: var(--surface);
}

article.single-post > .markdown-body p {
  text-align: left;
}

article.single-post > .markdown-body > * {
  margin-bottom: 0.75rem !important;
}

article.single-post > .markdown-body > p:has(img) {
  text-align: center;
}

article.single-post > .markdown-body > p > img {
  object-fit: cover;
  object-position: center;
  max-height: 80dvh;
  max-width: 100%;
  text-align: center;
  border-radius: 0.75rem;
}

article.single-post > .markdown-body > .video {
  display: flex;
  justify-content: center;
}

article.single-post > .markdown-body > .video > video {
  max-height: 80dvh;
  max-width: 100%;
  border-radius: 0.75rem;
}

.lightense-backdrop {
  background-color: var(--background) !important;
}

.author_link {
  font-weight: bold;
  color: var(--outline);
}

.modal_status {
  top: 30%;
}

.deemphasisze {
  display: inline;
  text-transform: uppercase;
  font-size: 0.8em;
  font-weight: bold;
  color: var(--outline);
}
